pro make_magmock, event, magmock, mag_0, mag_1, n_mock, kb, iseed
;
;	models numbers of stars vs magnitude to match power law selected between limits
;	selected
;
;---------------------------------------
;
;	model:   Log_10((N(m) dm)) = ka + kb * m
;
;		where: 	N(m)dm is the number of stars between magnitude m and m+dm
;				a is an offset to determine
;				b is the power law index (mag_pwr_law)
;
;--------------------------------------
;
iplot = 0				; 1 for debug plotting
;
print_text, Event, 'Generating mock stars. Number requested = '+STRING(n_mock,format='(I)')
;
gamma = 10.0d0^(mag_1 * kb) - 10.0d0^(mag_0 * kb)
;
mx = (1.0d0/kb) * alog10(10.0d0^(mag_0 * kb) + gamma * RANDOMU(iseed, n_mock))
;
hmx = mx		; save a copy to prevent histogram from reordering
;
;stop
;
y = histogram(hmx,min=mag_0,max=mag_1,nbins=61,locations=x)
ylog = alog10(y)
ind = WHERE(FINITE(ylog),nfinite)
n = TOTAL(y[ind])
print_text, event, 'Number of good mock star magnitudes generated = '+STRING(n,format='(I)')
;	;
if(iplot eq 1) then begin
	print_text, Event, 'number of finite bins in Log(N) vs mag = '+STRING(nfinite,format='(I)')+' of 61 tried'
	y0 = min(ylog[ind])
	y1 = max(ylog[ind])
	dy = y1 - y0
	y0 -= 0.05*dy
	y1 += 0.05*dy
	window, 11, title='Histogram of Mock Star Magnitudes Generated'
	plot, x[ind], ylog[ind], psym=10, xr=[mag_0,mag_1],xs=1,yr=[y0,y1],ys=1,$
		xtitle='Magnitude',ytitle='Log(Number per mag bin)'
	;
	;
	window, 12,title='Cumulative Histogram of Mock Star Magnitudes Generated'
	xx = x[ind]
	yy = TOTAL(y[ind],/cumulative)
	yy = alog10(yy)
	ymin = min(yy)
	ymin >= -0.2
	yr = [ymin,max(yy)]
	plot, xx, yy, psym=10, xr=[mag_0,mag_1],xs=1,yr=yr,ys=1,$
		xtitle='Magnitude',ytitle='Log(Cumulative Number per mag bin)'
	cursor, xx1, yy1, /wait
	wait, 1
	;
	wdelete, 12
	wdelete, 11
endif
;
ind_mag = WHERE(mx ge mag_0 and mx le mag_1,nmag)
print_text, event, 'Number of good mock star magnitudes within mag limits = '+STRING(nmag,format='(I)')
magmock = mx[ind_mag]
;
end

