pro make_mock_image, mock_image, S8_PSF_Model, xmock, ymock, magmock, pmock, pamock, $
					hwp;, PA_offset, Q_Inst_Image, U_Inst_Image
;
;	takes a clean input image (mock_image) and the PSF model structure and the
;	vectors of x,y,mag,p,pa for each of the mock stars, and generates suitable
;	representations in the image, returing the filled image
;
;	hwp is the hwp number (-1 is deep phot, so no pol
;							0 is PA=0,
;							1 is PA=45
;							2 is PA=90
;							3 is PA=135  and the cycle repeats after that)
;
n_mock = N_ELEMENTS(xmock)
;
;ng = 6
;
;	test for fewer zones fit
;
nd = SIZE(S8_PSF_Model.gauss_fit,/N_DIMENSIONS)
if(nd eq 1) then begin
	ng = 1
endif else begin
	ns = SIZE(S8_PSF_Model.gauss_fit)
	if(ns[2] eq 3) then ng = 3 else ng = 6
endelse
;
;	for each star
;
for i = 0, n_mock - 1 do begin
	;
	this_x = xmock[i]
	this_y = ymock[i]
	;
	;	create PSF model star
	;
	resid = make_PSF(ng, this_x, this_y, S8_PSF_Model, PSF_gaussian, PSF_rad, PSF_mag, $
						sum_resid_f, fit_rad, status)
	;
	;	smooth the residuals with a 2.0 pixel FWHM gaussian
	;
	gsmooth, resid, FWHM=2.0
	;
	g_remake_PSF, PSF_gaussian, resid, PSF_rad, psf_image, PSF_mag, fit_rad
	;
	;	writefits, dialog_pickfile(Title="PSF FITS file to save"),psf_image
	;
	;	scale star to correct magnitude
	;
	dmag = magmock[i] - PSF_mag
	;
	scale = 10^(-0.4*dmag)
	;
	;	for debugging
	;
;	print, 'Star=',i,', Gaussian Gain=',S8_PSF_Model.gauss_fit[0],', Magmock=',magmock[i],', PSF_mag=',PSF_mag,$
;				', scale=',scale,', max(psf_image) [B4 scaling]=',max(psf_image)
	;
	psf_image *= scale
	;
;	print, '     max(psf_image) [after scaling] = ',max(psf_image)
	;
	;	polarization modulation
	;
	;*****************************************
	;
	;	fix PA_off and P_inst(Q), P_inst(U) for now - later they will be looked up
	;
	PA_off = 0.0				; degrees
	P_inst_U = 0.0				; fractional (0-100%)
	P_inst_Q = 0.0				; fractional
	;
	dtor = !DPI/180.0d0
	;
	this_Q = P_inst_Q + pmock[i] * cos(2.0d0*dtor*(pamock[i] + PA_off))
	this_U = P_inst_U + pmock[i] * sin(2.0d0*dtor*(pamock[i] + PA_off))
	;
	this_Q /= 100.0
	this_U /= 100.0
	;
	normal_I_0 = 0.5d0 * (1.0d0 + this_Q)		; I_0 / I
	normal_I_45 = 0.5d0 * (1.0d0 - this_U)
	normal_I_90 = 0.5d0 * (1.0d0 - this_Q)
	normal_I_135 = 0.5d0 * (1.0d0 + this_U)
	;
	;	what PA angle is this HWP?
	;
	if(hwp ge 0) then begin
		;
		;	skipped deep phot image
		;
		ia = hwp mod 4
		;
		case ia of
			0: stokes_scale = normal_I_0
			1: stokes_scale = normal_I_45
			2: stokes_scale = normal_I_90
			3: stokes_scale = normal_I_135
		endcase
		;
		stokes_scale *= 2.0					; since we are modifying existing intensities, not computing new ones
		psf_image *= stokes_scale
	endif
	;
	;	place into mock_image
	;
	psize = SIZE(psf_image)
	px = psize[1]
	py = psize[2]
	;
	xoff = floor(float(px)/2.-0.45)
	yoff = floor(float(py)/2.-0.45)
	;
	mock_image[[this_x - xoff]:[this_x + xoff],[this_y - yoff]: [this_y + yoff]] += psf_image[*,*]
	;
	;	next star
	;
endfor
;
;	done
;
end
