pro tab_1_routines, Event
	;
	;	stub to allow Tab 1 routines to be collected in one file
	;
end
;
;--------------------------------------------------------
pro Change_Trial_Run_Directory, Event
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR_Struct
	s_ptr = PTR_Struct.PTR_summary
	w_ptr = PTR_Struct.PTR_wid
	;
	;	use file chooser to select the Trial/Run Source directory
	;
	;	check that the choice points to a directory with "Run" in its name
	;
	new_dir = dialog_pickfile(Title='Select Trial/Run file source directory',/directory)
	;
	;	check result
	;
	split_path, Event, new_dir, root_path, root_name
	;
	result = STRPOS(STRUPCASE(root_name),STRUPCASE("Run"))
	if(result ne -1) then begin
		(*w_ptr).Source_Directory_Name = new_dir
		print_text, event, 'Trial/Run Source Directory set to = '+new_dir
		;
		;	update textbox
		;
		WIDGET_CONTROL, (*w_ptr).Source_Directory_Textbox_wid, SET_VALUE=(*w_ptr).Source_Directory_Name
		;
		;	next, go to that directory and get the observation root name and the list of files to
		;	move. Note that if there is only one (deep) file, that will be all that is transferred
		;
		source_dir = new_dir + PATH_SEP() + 'Output_Images' + PATH_SEP()
		;
		files = FILE_SEARCH(source_dir+'*.*',COUNT=nf)
		if(nf gt 0) then begin
			for i = 0, nf-1 do begin
				(*w_ptr).File_Copy_List[i] = files[i]
			endfor
			if(nf eq 1) then begin
				(*w_ptr).File_Copy_List[1:16] = 'no file'
			endif
			;
			;	put on textbox
			;
			WIDGET_CONTROL, (*w_ptr).File_Copy_Textbox_wid,SET_VALUE=FILE_BASENAME((*w_ptr).File_Copy_List)
			print_text, event, 'Found '+STRING(nf,format='(I)')+' images to copy in the Run_NN directory'
		endif else begin
			print_text, event, 'ERROR - no files found in the designated Run_NN directory'
;			stop
		endelse
		;
	endif else begin
		print_text, event, 'Selected Directory must be of Run_NN type. Try again'
;		stop
	endelse
end
;
;--------------------------------------------------------
pro Change_Destination_Directory, Event
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR_Struct
	s_ptr = PTR_Struct.PTR_summary
	w_ptr = PTR_Struct.PTR_wid
	;
	;	use file chooser to point to PPOL Step 7 directory
	;
	new_dir = dialog_pickfile(Title='Select PPOL/Step 7 directory',/directory)
	;
	;	test that we are pointed to the correct subdirectory
	;
	result = STRPOS(STRUPCASE(new_dir),STRUPCASE("S7_Coadding"))
	if(result ne -1) then begin
		(*w_ptr).Destination_Directory = new_dir
		print_text, event, 'Destination Directory set to = '+new_dir
		;
		;	update textbox
		;
		WIDGET_CONTROL, (*w_ptr).Destination_Directory_Textbox_wid, SET_VALUE=(*w_ptr).Destination_Directory
		;
	endif else begin
		print_text, event, 'Selected Directory must be of S7_Coadding type. Try again'
;		stop
	endelse
	;
end
;
;--------------------------------------------------------
pro Start_File_Copy, Event
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR_Struct
	s_ptr = PTR_Struct.PTR_summary
	w_ptr = PTR_Struct.PTR_wid
	;
	;	copies the modeled mock+real image to the designated step 7 PPOL directory
	;
	(*w_ptr).Copy_Results = 'copying'
	WIDGET_CONTROL, (*w_ptr).Copy_Results_Textbox_wid,SET_VALUE=(*w_ptr).Copy_Results
	if( (*w_ptr).No_HWP_flag eq 0) then colors = strarr(17) else colors = strarr(1)
	colors[*] = 'yellow'
	;
	;	first deep, then HWP (if any are present)
	;
	deep_out = (*w_ptr).Destination_Directory + PATH_SEP() + FILE_BASENAME( (*w_ptr).File_Copy_List[0] )
	;
	;	verify source file exists
	;
	result = FILE_TEST((*w_ptr).File_Copy_List[0])
	if(result eq 1) then begin
		FILE_COPY, (*w_ptr).File_Copy_List[0], deep_out, /OVERWRITE
		colors[0] = 'green' & LED_stack, (*w_ptr).Copy_Results_Window_wid, colors
		print_text, event, 'Copied '+FILE_BASENAME( (*w_ptr).File_Copy_List[0])+' from Run directory to Step 7 PPOL directory'
	endif else begin
		print_text, event, 'ERROR - input (mock+real star image) file does not exist. Abandoning.'
		goto, quick_exit
	endelse
	(*w_ptr).Copy_Results = 'Deep Copied'
	WIDGET_CONTROL, (*w_ptr).Copy_Results_Textbox_wid,SET_VALUE=(*w_ptr).Copy_Results
	;
	;	HWP images - if flag set or the first doesn't exist, then assume only deep image was created, in that
	;					case, end nicely
	;
	result = FILE_TEST((*w_ptr).File_Copy_List[1])
	if(result eq 1) then begin
		;
		;	for each HWP image
		;
		for i = 0, 15 do begin
			;
			;	same order, check images, then copy
			;
			result = FILE_TEST((*w_ptr).File_Copy_List[i+1])
			hwp_out = (*w_ptr).Destination_Directory + PATH_SEP() + FILE_BASENAME( (*w_ptr).File_Copy_List[i+1] )
			if(result eq 1) then begin
				FILE_COPY, (*w_ptr).File_Copy_List[i+1], hwp_out, /OVERWRITE
				colors[i+1] = 'green' & LED_stack, (*w_ptr).Copy_Results_Window_wid, colors
				print_text, event, 'Copied '+FILE_BASENAME( (*w_ptr).File_Copy_List[i+1])+' from Run directory to Step 7 PPOL directory'
			endif else begin
				print_text, event, 'ERROR - input (mock+real star image) file does not exist. Abandoning.'
				goto, quick_exit
			endelse
		endfor
		;
		(*w_ptr).Copy_Results = 'HWP'+STRING(i+1,format='(I)')+' Copied'
		WIDGET_CONTROL, (*w_ptr).Copy_Results_Textbox_wid,SET_VALUE=(*w_ptr).Copy_Results
		;
	endif else begin
		print_text, event, 'No HWP images found. Assuming only Deep Image Created. Exiting normally.'
	endelse
	;
	quick_exit:
	(*w_ptr).Copy_Results = 'done'
	WIDGET_CONTROL, (*w_ptr).Copy_Results_Textbox_wid,SET_VALUE=(*w_ptr).Copy_Results
	;
	print_text, event, 'All Image Files have been copied. Finished'
	print_text, event, 'Begin MSP-PPOL analysis at Step 8, with fix-2MASS flag selected'
end

